sphinxcontrib_qthelp: Sphinx extension which outputs QtHelp documents
=====================================================================

Description
-----------

Sphinx extension which outputs QtHelp documents

License
-------

BSD
